<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>main</name>
    <message>
        <source>Optimal performance</source>
        <translation>最佳性能</translation>
    </message>
    <message>
        <source>Balance</source>
        <translation>均衡</translation>
    </message>
    <message>
        <source>Best Visuals</source>
        <translation>最佳视觉</translation>
    </message>
    <message>
        <source>Disable all interface and window effects for efficient system performance</source>
        <translation>关闭所有界面和窗口特效，保障系统高效运行</translation>
    </message>
    <message>
        <source>Limit some window effects for excellent visuals while maintaining smooth system performance</source>
        <translation>限制部分窗口特效，保障出色的视觉效果，同时维持系统流畅运行</translation>
    </message>
    <message>
        <source>Enable all interface and window effects for the best visual experience</source>
        <translation>启用所有界面和窗口特效，体验最佳视觉效果</translation>
    </message>
</context>
</TS>
